<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>התאמת הגדרות טעינת תמונות לכל אתר וגלובלית</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>הגדרות עמוד נוכחי</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>נטרל טעינת תמונות (זמנית)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>אפשר טעינת תמונות (זמנית)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>הגדרות גלובליות</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>טען אוטומטית תמונות</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>התאמת הגדרות לכל אתר וגלובלית</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>הגדרות עמוד נוכחי</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>נטרל JavaScript (זמנית)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>אפשר JavaScript (זמנית)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>הגדרות גלובליות</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>נהל הגדרות JavaScript</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation>תצורת Proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>בחר ציר</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>ריק</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>נהל צירים</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>הצגת מצב רשת תקשורת וניהול ציר&lt;br/&gt;&lt;br/&gt;&lt;b&gt;רשת:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;ציר:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>מחובר</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>לא מקוון</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>ציר מערכת</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>בלי ציר</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>מוגדר משתמש</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>מנהל Proxy</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>בחר ציר: </translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>הוסף ציר</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>הסר ציר</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>אין צירים. באפשרותך להוסיף ציר על ידי הקלקה על לחצן &lt;b&gt;הוסף&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>כדי שמור שינויים עליך להשתמש בלחצן &lt;b&gt;שמור&lt;/b&gt;.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>שם של ציר:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>הסרת ציר נוכחי</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation>האם אתה בטוח כי ברצונך להסיר ציר נוכחי?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>טופס</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>פורט:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>שם משתמש:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>סיסמה:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation>תצורת &amp;ציר של מערכת</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation>תצורה י&amp;דנית</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>צלמיות שורת מצב</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;צלמיות שורת מצב&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>צלמיות אלה יוצגו בשורת מצב:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>צלמית תמונות</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>צלמית JavaScript</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>צלמית רשת</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>זכוכית מגדלת</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>זום: %1%</translation>
    </message>
</context>
</TS>